@@ -18,6 +18,7 @@ class MQ(object):
             self,  # pylint: disable=unused-argument
             redisHost="localhost",
             redisPort=6379,
+            redisPassword="",
             redisRealtime=False,
             redisKeepalive=True,
             # redisKeepaliveIDLE=120,
@@ -35,6 +36,7 @@ class MQ(object):
         self.options.update(
             host=redisHost,
             port=redisPort,
+            password=redisPassword,
             realtime=redisRealtime,
             keepalive=redisKeepalive,
             # keepidle=redisKeepaliveIDLE,
